assert_that_raster_covers_las_point_cloud: Assert that the extent of a raster covers that of a LAS point...

View source: R/validation_functions.R

assert_that_raster_covers_las_point_cloudR Documentation

Assert that the extent of a raster covers that of a LAS point cloud

Description

Assert that the extent of a raster covers that of a LAS point cloud

Usage

assert_that_raster_covers_las_point_cloud(raster, las_point_cloud, message)

Arguments

raster

A SpatRaster.

las_point_cloud

Point cloud data in lidR::LAS format.

message

Length-one character vector. Message to be used on assertion failure.


crownsegmentr documentation built on Sept. 22, 2026, 5:09 p.m.