match_any: Find all exact matches with at least one of the provided...

View source: R/extract_coordinate_values.R

match_anyR Documentation

Find all exact matches with at least one of the provided patterns

Description

Find all exact matches with at least one of the provided patterns

Usage

match_any(patterns, targets)

Arguments

patterns

Objects which will be matched to targets via the == operator.

targets

Objects which will be matched to each of the patterns.

Value

A boolean vector of the same length as targets.


crownsegmentr documentation built on Sept. 22, 2026, 5:09 p.m.