| remove_small_trees | R Documentation |
The function takes a point cloud in which trees were segmented, and removes tree clusters that are smaller than a certain radius or a certain height
remove_small_trees(
point_cloud,
min_radius = 1,
min_height = -Inf,
crown_id_column_name = "crown_id"
)
## S4 method for signature 'data.frame'
remove_small_trees(
point_cloud,
min_radius = 1,
min_height = -Inf,
crown_id_column_name = "crown_id"
)
## S4 method for signature 'LAS'
remove_small_trees(
point_cloud,
min_radius = 1,
min_height = -Inf,
crown_id_column_name = "crown_id"
)
## S4 method for signature 'LAScatalog'
remove_small_trees(
point_cloud,
min_radius = 1,
min_height = -Inf,
crown_id_column_name = "crown_id"
)
point_cloud |
a point cloud, either as data.frame/data.table, or as lidR::LAS object. |
min_radius |
(Numeric >= 0) the threshold for crown radius, below which trees will be removed |
min_height |
(Numeric) the threshold for crown height, below which trees will be removed. Works only if las is normalized. |
crown_id_column_name |
the name of the column in which the id of the crown is saved |
lidR LAS
remove_small_trees(data.frame): removes small tree clusters in a segmented
LAS object.
remove_small_trees(LAS): removes small tree clusters in a segmented
LAS object.
remove_small_trees(LAScatalog): removes small tree clusters in a segmented
LAScatalog.
returns the same las object that was given as input, but with altered crown id's. Trees that are considered too small have their crown id set to NA, and all other crown id's are re-assigned so that they are without gaps
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.