View source: R/collect_scale_n_offset_of_LAScatalog_files.R
| collect_scale_n_offset_of_LAScatalog_files | R Documentation |
Get the scale and offset values of all files referenced by a LAScatalog
collect_scale_n_offset_of_LAScatalog_files(LAScatalog)
A data.table with 7 columns. The first three columns hold the x, y, and z scale factors, the next three columns hold the x, y, and z offsets and the last column holds the file paths. There is one row for each referenced file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.