Learn R Programming

crownsegmentr (version 1.0.1)

collect_scale_n_offset_of_LAScatalog_files: Get the scale and offset values of all files referenced by a LAScatalog

Description

Get the scale and offset values of all files referenced by a LAScatalog

Usage

collect_scale_n_offset_of_LAScatalog_files(LAScatalog)

Arguments

Value

A data.table with 7 columns. The first three columns hold the x, y, and z scale factors, the next three columns hold the x, y, and z offsets and the last column holds the file paths. There is one row for each referenced file.