match_any: Find all exact matches with at least one of the provided patterns
Description
Find all exact matches with at least one of the provided patterns
Usage
match_any(patterns, targets)
Value
A boolean vector of the same length as targets.
Arguments
- patterns
Objects which will be matched to targets via the ==
operator.
- targets
Objects which will be matched to each of the patterns.